@@ -461,15 +461,17 @@ namespace giac {
     gen operator () (const gen & arg,GIAC_CONTEXT) const;
 #ifdef NO_UNARY_FUNCTION_COMPOSE
     inline unary_function_eval * ptr() const {
+      return (unary_function_eval *) (((size_t) _ptr) & ~(uintptr_t)3);
 #ifdef x86_64
-      return (unary_function_eval *) (((ulonglong ) _ptr) & 0xfffffffffffffffc);
+      //return (unary_function_eval *) (((ulonglong ) _ptr) & 0xfffffffffffffffc);
 #else
-      return (unary_function_eval *) (((size_t) _ptr) & 0xfffffffc);
+      //return (unary_function_eval *) (((size_t) _ptr) & 0xfffffffc);
 #endif
     }
 #else // NO_UNARY_FUNCTION_COMPOSE
     inline unary_function_abstract * ptr () const
     {
+      return (unary_function_abstract *) (((ulonglong ) _ptr) & ~(uintptr_t)3);
 #ifdef x86_64
       return (unary_function_abstract *) (((ulonglong ) _ptr) & 0xfffffffffffffffc);
 #else
@@ -480,19 +482,21 @@ namespace giac {
     bool quoted() const ;
     inline bool operator ==(const unary_function_ptr & u) const { 
       // if (&u==this) return true; 
+      return ((ulonglong)(_ptr) & ~(uintptr_t)3 )  == ((ulonglong)( u._ptr) & ~(uintptr_t)3 );
 #ifdef x86_64
-      return ((ulonglong)(_ptr) & 0xfffffffffffffffc)  == ((ulonglong)( u._ptr) & 0xfffffffffffffffc ); 
+      //return ((ulonglong)(_ptr) & 0xfffffffffffffffc)  == ((ulonglong)( u._ptr) & 0xfffffffffffffffc ); 
 #else
-      return ((size_t)(_ptr) & 0xfffffffc) == ((size_t)(u._ptr) & 0xfffffffc); 
+      //return ((size_t)(_ptr) & 0xfffffffc) == ((size_t)(u._ptr) & 0xfffffffc); 
 #endif
     }
     inline bool operator !=(const unary_function_ptr & u) const { return !(*this==u); }
     inline bool operator ==(const unary_function_ptr * u) const { 
       // if (&u==this) return true; 
+      return u && ( ((ulonglong)(_ptr) &  ~(uintptr_t)3 ) == ((ulonglong)(u->_ptr) &  ~(uintptr_t)3) ); 
 #ifdef x86_64
-      return u && ( ((ulonglong)(_ptr) & 0xfffffffffffffffc) == ((ulonglong)(u->_ptr) & 0xfffffffffffffffc) ); 
+      //return u && ( ((ulonglong)(_ptr) & 0xfffffffffffffffc) == ((ulonglong)(u->_ptr) & 0xfffffffffffffffc) ); 
 #else
-      return u && ( ((size_t)(_ptr) & 0xfffffffc) == ((size_t)(u->_ptr) & 0xfffffffc ) ); 
+      //return u && ( ((size_t)(_ptr) & 0xfffffffc) == ((size_t)(u->_ptr) & 0xfffffffc ) ); 
 #endif
     }
     inline bool operator !=(const unary_function_ptr * u) const { return !(*this==u); }
@@ -666,7 +670,15 @@ namespace giac {
     }
 
     bool in_eval(int level,gen & evaled,const context * contextptr) const;
-    gen eval(int level,const context * contextptr) const;
+    inline gen eval(int level,const context * contextptr) const{
+      // CERR << "eval " << *this << " " << level << endl;
+      gen res;
+      // return in_eval(level,res,contextptr)?res:*this;
+      if (in_eval(level,res,contextptr))
+	return res;
+      else
+      return *this;
+    }
     // inline gen eval() const { return eval(DEFAULT_EVAL_LEVEL,context0); }
     bool in_evalf(int level,gen & evaled,const context * contextptr) const;
     gen evalf(int level,const context * contextptr) const;
@@ -681,7 +693,7 @@ namespace giac {
       // Copy before deleting because the target might be embedded in a
       // with a ptr_val.ref_count of a equals to 1
       // short int type_save=type; // short int subtype_save=subtype; 
-      * ((longlong *) this) = al;
+      * ((ulonglong *) this) = al;
       if (atype>_DOUBLE_ && atype!=_FLOAT_ 
 	  && (al >> 16)	){
 	ref_count_t * rc=(ref_count_t *)& ((ref_mpz_t *)(al>>16) )->ref_count;
@@ -717,7 +729,7 @@ namespace giac {
       _DOUBLE_val = a._DOUBLE_val;
       subtype=a.subtype;
 #else
-      * ((longlong *) this) = *((longlong * ) &a);
+      * ((ulonglong *) this) = *((ulonglong * ) &a);
 #endif
       __ZINTptr=a.__ZINTptr;
       type=a.type;
@@ -939,6 +951,7 @@ namespace giac {
   gen operator && (const gen & a,const gen & b);
   gen operator || (const gen & a,const gen & b);
   gen operator_plus (const gen & a,const gen & b,GIAC_CONTEXT);
+  gen operator_plus (const gen & a,const gen & b,unsigned t,GIAC_CONTEXT);
   gen operator + (const gen & a,const gen & b);
   gen & operator_plus_eq (gen & a,const gen & b,GIAC_CONTEXT);
   inline gen & operator += (gen & a,const gen & b){ 
@@ -1026,6 +1039,7 @@ namespace giac {
 
   int fastsign(const gen & a,GIAC_CONTEXT);   // 0 if unknown, 1 if >0, -1 if <0
   gen sign(const gen & a,GIAC_CONTEXT);
+  inline int signint(int i){ return i?(i>0?1:-1):0;}
 
   // Large tests if strictly not precised, if sign is unknown return false 
   bool is_greater(const gen & a,const gen &b,GIAC_CONTEXT);
@@ -1033,6 +1047,9 @@ namespace giac {
   inline bool operator > (const gen & a,const gen & b){
     return is_strictly_greater(a,b,giac::context0);
   }
+  inline bool operator < (const gen & a, const gen & b) {
+    return is_strictly_greater (b, a, giac::context0);
+  }
   bool is_positive(const gen & a,GIAC_CONTEXT);
   bool is_strictly_positive(const gen & a,GIAC_CONTEXT);
   // Large tests if strictly not precised, if sign is unknown make an error
@@ -1640,6 +1657,26 @@ namespace giac {
 
   extern "C" const char * caseval(const char *);
 
+// Alloca proposal by Cyrille to make it work on every compiler.
+#ifndef ALLOCA
+  // alloca versions...
+  #if defined(FREERTOS)
+    // for systems that do not support alloca or s[size] syntaxes
+    class Calloca { public:
+      void *ram;
+      Calloca(size_t s): ram(malloc(s)) { }
+      ~Calloca() { free(ram); }
+    };
+    #define ALLOCA(type, var, size) Calloca alloca##var(size); type *var= (type*)(alloca##var.ram)
+  #else
+    #if defined( VISUALC ) || defined( BESTA_OS )
+      #define ALLOCA(type, var, size) type *var= (type*)alloca(size)
+    #else
+      #define ALLOCA(type, var, size) type var[size]
+    #endif
+  #endif
+#endif
+
 #ifndef NO_NAMESPACE_GIAC
 } // namespace giac
 #endif // ndef NO_NAMESPACE_GIAC
