@@ -86,7 +86,7 @@ extern const unary_function_ptr * const  at_Eta;
 extern const unary_function_ptr * const  at_Exec;
 extern const unary_function_ptr * const  at_FLOOR;
 extern const unary_function_ptr * const  at_FNROOT;
-extern const unary_function_ptr * const  at_FP;
+extern const unary_function_ptr * const  at_FRAC;
 extern const unary_function_ptr * const  at_Factor;
 extern const unary_function_ptr * const  at_Fahrenheit2Celsius;
 extern const unary_function_ptr * const  at_Fill;
@@ -107,7 +107,7 @@ extern const unary_function_ptr * const  at_IM;
 extern const unary_function_ptr * const  at_INPUT;
 extern const unary_function_ptr * const  at_INTERSECT;
 extern const unary_function_ptr * const  at_INVERSE;
-extern const unary_function_ptr * const  at_IP;
+extern const unary_function_ptr * const  at_INT;
 extern const unary_function_ptr * const  at_ISOLATE;
 extern const unary_function_ptr * const  at_ITERATE;
 extern const unary_function_ptr * const  at_Input;
@@ -747,7 +747,7 @@ extern const unary_function_ptr * const  at_iegcd;
 extern const unary_function_ptr * const  at_ifactor;
 extern const unary_function_ptr * const  at_ifactors;
 extern const unary_function_ptr * const  at_ifft;
-extern const unary_function_ptr * const  at_igamma;
+extern const unary_function_ptr * const  at_lower_incomplete_gamma;
 extern const unary_function_ptr * const  at_igamma_exp;
 extern const unary_function_ptr * const  at_igcd;
 extern const unary_function_ptr * const  at_igcdex;
@@ -808,7 +808,7 @@ extern const unary_function_ptr * const  at_is_harmonic;
 extern const unary_function_ptr * const  at_is_harmonic_circle_bundle;
 extern const unary_function_ptr * const  at_is_harmonic_line_bundle;
 extern const unary_function_ptr * const  at_is_included;
-extern const unary_function_ptr * const  at_is_inside;
+extern const unary_function_ptr * const  at_est_dans;
 extern const unary_function_ptr * const  at_is_isosceles;
 extern const unary_function_ptr * const  at_is_orthogonal;
 extern const unary_function_ptr * const  at_is_parallel;
@@ -1191,7 +1191,7 @@ extern const unary_function_ptr * const  at_reduced_conic;
 extern const unary_function_ptr * const  at_reduced_quadric;
 extern const unary_function_ptr * const  at_ref;
 extern const unary_function_ptr * const  at_reflection;
-extern const unary_function_ptr * const  at_regroup;
+extern const unary_function_ptr * const  at_regrouper;
 extern const unary_function_ptr * const  at_rem;
 extern const unary_function_ptr * const  at_remain;
 extern const unary_function_ptr * const  at_remove;
@@ -1407,7 +1407,7 @@ extern const unary_function_ptr * const  at_tsimplify;
 extern const unary_function_ptr * const  at_turtle_stack;
 extern const unary_function_ptr * const  at_type;
 extern const unary_function_ptr * const  at_ufactor;
-extern const unary_function_ptr * const  at_ugamma;
+extern const unary_function_ptr * const  at_upper_incomplete_gamma;
 extern const unary_function_ptr * const  at_unapply;
 extern const unary_function_ptr * const  at_unarchive;
 extern const unary_function_ptr * const  at_unarchive_ti;
